@@ -19,25 +19,26 @@ sub run {
 
     my $app = Riji->new;
     my $conf = $app->config;
-    my $repo = $app->model('Blog')->repo;
+    my $blog = $app->model('Blog');
+    my $repo = $blog->repo;
     my $force = grep {$_ eq '--force'} @argv;
 
     # `git symbolic-ref --short` is available after git 1.7.10, so care older version.
     my $current_branch = $repo->run(qw/symbolic-ref HEAD/);
        $current_branch =~ s!refs/heads/!!;
-    my $publish_branch = $app->model('Blog')->branch;
+    my $publish_branch = $blog->branch;
     unless ($force){
         my $force_announce = "or you can use --force option\n";
         if ($publish_branch ne $current_branch) {
-            die "You need at publish branch [$publish_branch], so `git checkout $publish_branch` beforehand\n$force_announce";
+            die "You need at publish branch [$publish_branch], so `git checkout $publish_branch` beforehand $force_announce";
         }
 
-        if ( my $untracked = $repo->run(qw/ls-files --others --exclude-standard/) ) {
-            die "Unknown local files:\n$untracked\n\nUpdate .gitignore, git add them\n$force_announce";
+        if ( my $untracked = $repo->run(qw/ls-files --others --exclude-standard --/, $blog->entry_dir) ) {
+            die "Unknown local files:\n$untracked\n\ngit add them, update .gitignore $force_announce";
         }
 
-        if (my $uncommited = $repo->run(qw/diff HEAD --name-only/) ) {
-            die "Found uncommited changes:\n$uncommited\n\ncommit them beforehand\n$force_announce";
+        if (my $uncommited = $repo->run(qw/diff HEAD --name-only --/, $blog->entry_dir) ) {
+            die "Found uncommited changes:\n$uncommited\n\ncommit them beforehand $force_announce";
         }
     }
 
